@@ -1,5 +1,5 @@
 ceRNA.surv <-
-function(ceRNA,exp.sur,train=NULL,test=NULL,index=1){
+function(ceRNA,exp.sur,train=NULL,test=NULL,index){
  if(is.null(train)&is.null(train)){
      wr<-as.data.frame(matrix(ncol=10,nrow=length(index)),stringsAsFactors=F)
      colnames(wr)<-c("targetce","anotherce","coef_targetce","p_targetce","coef_anotherce","p_anotherce","N_low","N_high","HR","p")
